@@ -9,10 +9,10 @@ module Rack
         def initialize(app, realm = nil, &authenticator)
           @app = app
           @realm = realm
-          super &authenticator
+          super(&authenticator)
         end
 
-        def call(env)
+        def _call(env)
           if request.oauth2?
             access_token = authenticate! request.setup!
             env[ACCESS_TOKEN] = access_token
